@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.024_01';
+our $VERSION = '0.024_02';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -551,7 +551,7 @@ sub alien_check_installed_version {
   my $command = $self->alien_version_check;
 
   my %result = $self->do_system($command, {verbose => 0});
-  my $version = $result{stdout} || 0;
+  my $version = ($result{success} && $result{stdout}) || 0;
 
   return $version;
 }
@@ -829,11 +829,14 @@ sub do_system {
 
   print "+ @args\n";
 
+  my $old_super_verbose = $self->verbose;
+  $self->verbose(0);
   my ($out, $err, $success) = 
     $verbose
     ? tee     { $self->SUPER::do_system(@args) }
     : capture { $self->SUPER::do_system(@args) }
   ;
+  $self->verbose($old_super_verbose);
 
   my %return = (
     stdout => $out,
